% $Id: session.Rd,v 1.5 2003/04/04 13:50:44 warnes Exp $
%
% $Log: session.Rd,v $
% Revision 1.5  2003/04/04 13:50:44  warnes
%
% - Change 'T' to 'TRUE'
%
% Revision 1.4  2003/03/15 23:03:43  warnes
%
% - Clarified, spell-checked, and fixed a syntax error in help files.
%
% Revision 1.3  2002/04/30 14:20:01  warneg
%
% - Added texteval function & documentation
% - Added keywords to session.Rd
%
% Revision 1.2  2002/04/12 19:32:05  warneg
% - Added code to remove temporary variable used to store search path
%   and library path
% - Added cvs tags to the top of files
%
%

\name{save.session}
\alias{save.session}
\alias{restore.session}
\title{Save and restore session information, including loaded packages
  and attached data objects.}
\description{
  Save and restore session information, including loaded packages and
  attached data objects.
}
\usage{
save.session(file=".RSession", ...)
restore.session(file=".RSession", ...)
}
\arguments{
  \item{file}{ Filename for the session information. }
  \item{\dots}{ Optional arguments for \code{save()} or \code{load()}. }
}
\details{
  These two functions save and restore R session information.  In
  addition to the objects in the session, the list of currently loaded
  packages and the search path are (re)stored.

  Open graphics devices, \code{sinks}s, pipes, etc. will not be stored.
  \code{save.session} issues a  warning to this effect if any graphics
  devices are open. 
}
\value{
  No return value.
}
\author{ Gregory R. Warnes \email{gregory\_r\_warnes@groton.pfizer.com}}
\note{ Future enhancements may allow the restoration of the size,
  location, and graphics settings of graphics devices. }

\seealso{ \code{\link{save}}, \code{\link{save.image}},
  \code{\link{load}} }

\examples{

  ls(all=TRUE) # show all data objects
  search()  # list search path

  # save the current R session to the file "RSession.Rda"
  save.session("RSession.Rda")

  \dontrun{
  # exit R without saving data
  q("no")

  # restart R
  R 
  }

  # load a saved R session from "RSession.Rda"
  restore.session("RSession.Rda")

  ls(all=TRUE) # show all data objects
  search()  # list search path

}
\keyword{data}
\keyword{programming}


\eof
\name{texteval}
\alias{capture}
\alias{texteval}
\alias{printed}
\title{Evaluate string(s) containing R commands and return the text
  transcript or printed results}
\description{
  Evaluate string(s) containing R commands and return the text
  transcript or printed results
}
\usage{
capture(expression, collapse=NULL)
texteval(sourceText, collapse=NULL, echo=TRUE)
printed(sourceText, collapse=NULL)
}
\arguments{
  \item{expression}{ R expression to be evaluated }
  \item{sourceText}{ Vector of string to be evaluated.  }
  \item{collapse}{ Line separator. Defaults to \code{NULL} }
  \item{echo}{ Should commands be shown in output. Defaults to
    \code{TRUE} }
}
\details{
  \code{capture} captures the results of executing \code{expression}
  using a \code{textConnection}. \code{texteval} and \code{printed}
  parse and evaluate the contents of sourceText
  using \code{source} and the results are captured using a
  \code{textConnection}.  If \code{collapse} is NULL, a
  vector of strings is returned, one element for each line of output.
  (Empty strings for blank lines).  If \code{collapse} is non-NULL, the
  a single character string is formed by pasting the individuals
  elements together separated by this value.  When \code{echo} is TRUE,
  \code{texteval} will return a transcript that includes both printed
  output and evaluated commands. When \code{echo} is FALSE,
  \code{texteval} will return only the printed output.  \code{printed}
  always returns only the printed output.

  These functions were created to allow strings provided from external
  processes (for example by rpy or RSPerl) to be evaluated as if they
  were scripts.
}

\value{
  A single character string if \code{collapse} is non-NULL, otherwise a
  vector of character strings.
}

\author{ Gregory R. Warnes \email{gregory\_r\_warnes@groton.pfizer.com}}

\seealso{ \code{\link{source}}, \code{\link{textConnection}},
  \code{\link{sink}}, \code{\link{parse}}, \code{\link{eval}} 
}

\examples{

# define a script string
script <- "x <- rnorm(100)\ny <- x + rnorm(100,0.25)\nsummary(lm(y~x))"

# evaluate the script string, returning a transcript.
result <- texteval(script, "\n")
cat(result)

# evaluate the script string, returning the printed output.
result <- printed(script, "\n")
cat(result)

}
\keyword{data}
\keyword{programming}


\eof
